[![Format and Test](https://github.com/pyLiveNodes/LN-QT/actions/workflows/format_test.yml/badge.svg)](https://github.com/pyLiveNodes/LN-QT/actions/workflows/format_test.yml)
[![Publish](https://github.com/pyLiveNodes/LN-QT/actions/workflows/publish.yml/badge.svg)](https://github.com/pyLiveNodes/LN-QT/actions/workflows/publish.yml)

# LN QT

The Livenodes QT package provides interaction and visualization nodes. Most notably online annotation and display of any channels data.

[LiveNodes](https://livenodes.pages.csl.uni-bremen.de/livenodes/index.html) are small units of computation for digital signal processing in python. They are connected multiple synced channels to create complex graphs for real-time applications. Each node may provide a GUI or Graph for live interaction and visualization.

Any contribution is welcome! These projects take more time, than I can muster, so feel free to create issues for everything that you think might work better and feel free to create a MR for them as well!

Have fun and good coding!

Yale

## Installation

`pip install ln_qt `

## Docs

You can find the docs [here](https://livenodes.pages.csl.uni-bremen.de/packages/ln_qt/readme.html).

## Restrictions

None, just pure python and QT. Albeit, these make most sense when used with [Smart-Studio](https://livenodes.pages.csl.uni-bremen.de/smart-studio/readme.html).
